@@ -137,6 +137,9 @@ Out of the box implementation of the Construct without any override will set the
 
 © Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -199,7 +202,7 @@ class FargateToSns(
         :param encryption_key: An optional, imported encryption key to encrypt the SNS Topic with. Default: - None
         :param encryption_key_props: Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SNS Topic with. Default: - None
         :param existing_container_definition_object: -
-        :param existing_fargate_service_object: A Fargate Service already instantiated (probably by another Solutions Construct). If this is specified, then no props defining a new service can be provided, including: existingImageObject, ecrImageVersion, containerDefintionProps, fargateTaskDefinitionProps, ecrRepositoryArn, fargateServiceProps, clusterProps, existingClusterInterface. If this value is provided, then existingContainerDefinitionObject must be provided as well. Default: - none
+        :param existing_fargate_service_object: A Fargate Service already instantiated (probably by another Solutions Construct). If this is specified, then no props defining a new service can be provided, including: existingImageObject, ecrImageVersion, containerDefinitionProps, fargateTaskDefinitionProps, ecrRepositoryArn, fargateServiceProps, clusterProps, existingClusterInterface. If this value is provided, then existingContainerDefinitionObject must be provided as well. Default: - none
         :param existing_topic_object: Existing instance of SNS Topic object, providing both this and topicProps will cause an error.. Default: - Default props are used
         :param existing_vpc: An existing VPC in which to deploy the construct. Providing both this and vpcProps is an error. If the client provides an existing Fargate service, this value must be the VPC where the service is running. An SNS Interface endpoint will be added to this VPC. Default: - none
         :param fargate_service_props: Optional values to override default Fargate Task definition properties (fargate-defaults.ts). The construct will default to launching the service is the most isolated subnets available (precedence: Isolated, Private and Public). Override those and other defaults here. defaults - fargate-defaults.ts
@@ -314,7 +317,7 @@ class FargateToSnsProps:
         :param encryption_key: An optional, imported encryption key to encrypt the SNS Topic with. Default: - None
         :param encryption_key_props: Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SNS Topic with. Default: - None
         :param existing_container_definition_object: -
-        :param existing_fargate_service_object: A Fargate Service already instantiated (probably by another Solutions Construct). If this is specified, then no props defining a new service can be provided, including: existingImageObject, ecrImageVersion, containerDefintionProps, fargateTaskDefinitionProps, ecrRepositoryArn, fargateServiceProps, clusterProps, existingClusterInterface. If this value is provided, then existingContainerDefinitionObject must be provided as well. Default: - none
+        :param existing_fargate_service_object: A Fargate Service already instantiated (probably by another Solutions Construct). If this is specified, then no props defining a new service can be provided, including: existingImageObject, ecrImageVersion, containerDefinitionProps, fargateTaskDefinitionProps, ecrRepositoryArn, fargateServiceProps, clusterProps, existingClusterInterface. If this value is provided, then existingContainerDefinitionObject must be provided as well. Default: - none
         :param existing_topic_object: Existing instance of SNS Topic object, providing both this and topicProps will cause an error.. Default: - Default props are used
         :param existing_vpc: An existing VPC in which to deploy the construct. Providing both this and vpcProps is an error. If the client provides an existing Fargate service, this value must be the VPC where the service is running. An SNS Interface endpoint will be added to this VPC. Default: - none
         :param fargate_service_props: Optional values to override default Fargate Task definition properties (fargate-defaults.ts). The construct will default to launching the service is the most isolated subnets available (precedence: Isolated, Private and Public). Override those and other defaults here. defaults - fargate-defaults.ts
@@ -479,7 +482,7 @@ class FargateToSnsProps:
 
         If
         this is specified, then no props defining a new service can be provided, including:
-        existingImageObject, ecrImageVersion, containerDefintionProps, fargateTaskDefinitionProps,
+        existingImageObject, ecrImageVersion, containerDefinitionProps, fargateTaskDefinitionProps,
         ecrRepositoryArn, fargateServiceProps, clusterProps, existingClusterInterface. If this value
         is provided, then existingContainerDefinitionObject must be provided as well.
 
